package com.muyu.cloud.protocol.parsing;

import com.muyu.common.rabbit.MqttProperties;
import lombok.extern.log4j.Log4j2;
import org.eclipse.paho.client.mqttv3.MqttClient;
import org.eclipse.paho.client.mqttv3.MqttConnectOptions;
import org.eclipse.paho.client.mqttv3.MqttException;
import org.eclipse.paho.client.mqttv3.persist.MemoryPersistence;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Component;

/**
 * 创建mqtt实例
 * @Author: LiDongJia
 * @Package: com.muyu.cloud.protocol.parsing
 * @Project: cloud-server
 * @name: MqttPublishSample
 * @Date: 2024/10/10  14:33
 * @Description: 创建mqtt实例
 */
@Log4j2
@Component
public class MqttPublishSample {

    @Autowired
    private MqttCallbackMsg mqttCallbackMsg;

    /**
     * 连接MQTT Broker
     */
    public void connectToMqttBroker(MqttProperties mqttProperties) {
        try {
            // 创建MqttClient实例，指定Broker地址、客户端ID以及持久化方式
            MqttClient mqttClient = new MqttClient(mqttProperties.getBroker(), mqttProperties.getClientId(), new MemoryPersistence());
            // 连接MQTT Broker
            MqttConnectOptions connOpts = new MqttConnectOptions();
            connOpts.setCleanSession(true);
            connOpts.setUserName(mqttProperties.getUserName());
            connOpts.setPassword(mqttProperties.getPassword().toCharArray());
            log.info("连接到协议: " + mqttProperties.getBroker());
            mqttClient.connect(connOpts);
            mqttClient.subscribe(mqttProperties.getTopic(), 0);
            // 设置MQTT回调处理器
            mqttClient.setCallback(mqttCallbackMsg);
        } catch (MqttException me) {
            log.error("连接MQTT Broker失败: [{}]", me.getMessage());
        }
    }
}
